﻿using System;
using System.Collections.Generic;
using System.IO;

namespace StoreColumnOrder
{
    /// <summary>
    /// Interaction logic for PeopleListViewControl.xaml
    /// </summary>
    public partial class PeopleListView : IDisposable
    {
        public PeopleListView()
        {
            InitializeComponent();
            LoadColumnState();
        }

        void LoadColumnState()
        {
            if (File.Exists(SettingsFile))
            {
                bool deserializationSucceeded = true;
                List<String> columnOrder = null;
                try
                {
                    columnOrder = Serializer.DeserializeFromXML<List<string>>(SettingsFile);
                }
                catch (Exception)
                {
                    deserializationSucceeded = false;
                }
                if (deserializationSucceeded && columnOrder != null && columnOrder.Count > 0)
                {
                    int newIndex = 0;
                    foreach (var colName in columnOrder)
                    {

                        int oldIndex = 0;
                        for (int i = 0; i < PeopleGridView.Columns.Count; i++)
                        {
                            if (PeopleGridView.Columns[i].Header.ToString().Equals(colName))
                            {
                                oldIndex = i;
                                break;
                            }

                        }
                        PeopleGridView.Columns.Move(oldIndex, newIndex++);
                    }
                }
            }
        }

        void SaveColumnState()
        {
            if (!Directory.Exists(SettingsDirectory))
                Directory.CreateDirectory(SettingsDirectory);

            List<String> columnOrder = new List<string>();
            foreach (var col in PeopleGridView.Columns)
            {
                columnOrder.Add(col.Header.ToString());
            }
            Serializer.SerializeToXML(columnOrder, SettingsFile);
        }

        public string SettingsFile
        {
            get { return _XmlDirectory ?? Path.Combine(SettingsDirectory, "Columnsetings.xml"); }
            set { _XmlDirectory = value; }
        } private static string _XmlDirectory;

        public string SettingsDirectory
        {
            get { return Path.Combine(Environment.GetFolderPath(Environment.SpecialFolder.CommonApplicationData), "StoreColumnOrder"); }
        }

        #region IDisposable Members

        public void Dispose()
        {
            SaveColumnState();
        }

        #endregion
    }
}